package ocean.gateway.filters;

import java.lang.reflect.Field;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.web.client.TestRestTemplate;
import org.springframework.boot.web.server.LocalServerPort;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.util.Assert;

import ocean.gateway.service.ServiceApplication;
import ocean.gateway.service.filters.TokenFilter;


@RunWith(SpringRunner.class)
@SpringBootTest(classes = {ServiceApplication.class}, webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)

public class TokenFilterTests {
    
    @LocalServerPort
    int randomServerPort;

    @Autowired
    private TestRestTemplate restTemplate ;

    @Test
    public void GetHelloWithoutToken() {
        ResponseEntity<String> response = restTemplate.getForEntity("http://127.0.0.1:" + randomServerPort +"/hello", String.class);
        Assert.notNull(response, "The class must not be null");
        Assert.state(response.getStatusCode() == HttpStatus.UNAUTHORIZED, "response.getStatusCode() must be HttpStatus.UNAUTHORIZED");
    }

    @Test
    public void GetHelloWithToken() {
        String uri = "http://127.0.0.1:" + randomServerPort +"/hello";

        HttpHeaders headers = new HttpHeaders();
        String key = TokenFilter.TEST_TOKEN;

        headers.add("token",key);
        HttpEntity<String> entity = new HttpEntity<>("", headers);

        
        ResponseEntity<String> response = restTemplate.exchange(uri, HttpMethod.GET, entity, String.class);
        Assert.notNull(response, "The class must not be null");
        Assert.state(response.getStatusCode() != HttpStatus.UNAUTHORIZED, "response.getStatusCode() must not be HttpStatus.UNAUTHORIZED");
    }
}